function [umm]=myconv2d(km,um)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function [umm]=median2d(um,win)
% This function does a 2d windowed convolution on input image um with
% kernel km
% using homog neumann (reflection) boundary conditions, 
% where the buffer layer thickness is L = (win-1)/2. win = size(km,1);
% window is a matrix of size win x win. e.g. win = 3 ---> 3x3 window
% where median filter is applied
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Notes: No error checking is built in. Make sure size of input
%	 matrix is large enough: both dims. > 4 needed.
% also, window size must be odd so there is a center.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

m=size(um,1);
n=size(um,2);

win = size(km,1); %length of kernel
L = (win-1)/2; %1/2 length of window

umb = padnb(um,L); %reflection boundary conditions

%initialize output
umm = 0*um;

for i=L+1:L+m
    for j= L+1:L+n
        
        a = umb(i-L:i+L,j-L:j+L);
        %size(a)
        %L
        b = sum(sum(km.*a));
        %b = sum(reshape(a,1,win*win).*reshape(km,1,win*win));
        umm(i-L,j-L)=b;
        
    end
end


